@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import click
 
 from clusterone import config
@@ -17,7 +15,7 @@ from clusterone.utilities import append_to_docstring
 @click.argument(
     'value',
     )
-@append_to_docstring("Available values: {}".format(", ".join(CONFIGURABLE_PROPERTIES)))
+@append_to_docstring("Available keys: {}".format(", ".join(CONFIGURABLE_PROPERTIES)))
 def command(context, key, value):
     """
     Configure the CLI. Config is persistent.
