@@ -13,7 +13,7 @@ HEADER = ['Time', 'Job', 'Job Run ID', 'Status', 'Event']
 @click.option(
     '--once',
     is_flag=True,
-    help='See latest events. Just once.'
+    help='Display snapshot of latest events.'
     )
 @click.pass_obj
 @authenticate()
@@ -54,7 +54,7 @@ def output_events(client, before_printing=None):
     if before_printing:
         before_printing()
 
-    echo(make_table(events_data, header=HEADER))
+    echo(make_table(events_data, HEADER))
 
 
 def extract_data_from_events(events):
