@@ -28,6 +28,6 @@ def command(context, project_path):
 
     project = path_to_project(project_path, context=context)
     project_data = extract_data_from_project(project)
-    click.echo(make_table([project_data], header=HEADER))
+    click.echo(make_table([project_data], HEADER))
 
     return project
