@@ -8,18 +8,18 @@ from .helper import main
 @click.option(
     '--dataset-path',
     '-p',
-    help="Project identifier of format \"username/dataset\".",
+    help="Project identifier. Format \"username/dataset\".",
     required=True
     )
 @click.option(
     '--repo-path',
     '-r',
-    help="Path to local git repository.")
+    help="Path to local Git repository.")
 @click.pass_obj
 @authenticate()
 def command(context, dataset_path, repo_path):
     """
-    Links existing Clusterone dataset with a local git repository
+    Links existing Clusterone dataset with a local Git repository
     """
 
     client, session, cwd = context.client, context.session, context.cwd
@@ -33,7 +33,7 @@ def command(context, dataset_path, repo_path):
         if len(path_tokens) == 1:
             path_tokens = [session.get("username")] + path_tokens
         else:
-            raise BadParameter(param_hint="--dataset-path", message="Please provide a valid dataset-path. The format is \"username/dataset\".")
+            raise BadParameter(param_hint="--dataset-path", message="Please provide a valid dataset path. Format: \"username/dataset\".")
 
     username, dataset_name = path_tokens
 
