@@ -15,17 +15,17 @@ def is_data_on_stdin():
 @click.option(
     '--project-path',
     '-p',
-    help="Project identifier of format \"username/project\".")
+    help="Project identifier. Format \"username/project\".")
 @click.option(
     '--repo-path',
     '-r',
-    help="Path to local git repository.")
+    help="Path to local Git repository.")
 @click.pass_obj
 @authenticate()
 def command(context, project_path, repo_path):
     """
-    Links existing Clusterone project with a local git repository
-    Clusterone remote url can be passed through stdin
+    Links existing Clusterone project with a local Git repository
+        Clusterone remote url can be passed through stdin.
     """
 
     client, session, cwd = context.client, context.session, context.cwd
@@ -47,7 +47,7 @@ def command(context, project_path, repo_path):
             if len(path_tokens) == 1:
                 path_tokens = [session.get("username")] + path_tokens
             else:
-                raise BadParameter(param_hint="--project-path", message="Please provide a valid project-path. The format is \"username/project\".")
+                raise BadParameter(param_hint="--project-path", message="Please provide a valid project-path. Format: \"username/project\".")
 
         username, project_name = path_tokens
 
