@@ -28,7 +28,7 @@ def command(context, username, password, version_validator):
     Log into Clusterone
     """
 
-    client, config = context.client, context.config
+    client, session = context.client, context.session
 
     client.api_login(username, password)
 
@@ -36,9 +36,9 @@ def command(context, username, password, version_validator):
     del password
     gc.collect()
 
-    config['token'] = client.token
-    config['git_token'] = client.git_token
-    config['username'] = client.username
+    session['token'] = client.token
+    session['git_token'] = client.git_token
+    session['username'] = client.username
 
-    config.save()
+    session.save()
     echo("Login successful")
