@@ -1,7 +1,7 @@
 from click.testing import CliRunner
 
 from clusterone import ClusteroneClient
-from clusterone.config import Config
+from clusterone.persistance.session import Session
 from clusterone.clusterone_cli import cli
 
 from clusterone.commands.matrix import cmd
@@ -9,12 +9,12 @@ from clusterone.commands.matrix import cmd
 
 def test_opening(mocker):
     """
-    Call to click utility for browser controll
+    Call to click utility for browser control
     """
 
     mocker.patch.object(ClusteroneClient, '__init__', autospec=True, return_value=None)
-    mocker.patch.object(Config, 'save', autospec=True, return_value=None)
-    cmd.MATRIX_URL = "https://dummy/matrix"
+    mocker.patch.object(Session, 'save', autospec=True, return_value=None)
+    ClusteroneClient.matrix_url = "https://dummy/matrix"
 
     cmd.launch = mocker.Mock()
 
