@@ -2,7 +2,7 @@ import click
 from click import confirm
 
 from clusterone import authenticate
-from clusterone.client_exceptions import BussyProjectRemoveAttempt
+from clusterone.client_exceptions import BusyProjectRemoveAttempt
 from clusterone.utilities import path_to_project
 
 @click.command()
@@ -28,7 +28,7 @@ def command(context, project_path_or_id):
     )
 
     if project_has_running_jobs:
-        raise BussyProjectRemoveAttempt()
+        raise BusyProjectRemoveAttempt()
 
     confirm("Removing a project will remove all associated jobs and outputs. Are you sure?", abort=True)
 
