@@ -13,14 +13,14 @@ from clusterone.utilities import path_to_job_id
 @click.option(
     '--job-id',
     '-i',
-    help='Stop the job with the job with specified job id.')
+    help='ID of the job to stop.')
 @click.option(
     '--job-path',
     '-p',
-    help='Stop the job with matching path. A job path is “username/project/job-path.')
+    help='Path of the job to stop. Format: \"username/project/job-path\".')
 def command(context, job_path, job_id):
     """
-    Stop a job, either by name or id
+    Stop a running job, identified either by name or ID
     """
 
     client = context.client
