@@ -12,6 +12,7 @@ CONFIG_INSTANCE = Config()
 CLIENT_INSTANCE = ClusteroneClient(
     token=SESSION_INSTANCE.get('token'),
     username=SESSION_INSTANCE.get('username'),
-    api_url=CONFIG_INSTANCE.endpoint
+    api_url=CONFIG_INSTANCE.endpoint,
+    tls=CONFIG_INSTANCE.tls,
 )
 
