@@ -1,48 +1,36 @@
 # -*- coding: utf-8 -*-
 
-
+import requests
+import warnings
 import os
+
 import click
 import coreapi
 import py
-
-
-from coreapi import transports
-from coreapi.auth import TokenAuthentication
-
 from coreapi import Client
 from coreapi import codecs
-from raven import Client as RavenClient
-
+from coreapi import transports
+from coreapi.auth import TokenAuthentication
+from coreapi.exceptions import ErrorMessage
 
 from clusterone import client_exceptions
+from clusterone.client_exceptions import WrongNumberOfGPUs, NoCommitsInProjectFound, handle_api_error, \
+    NotebookCreationError
 from clusterone.utilities import lazy_property
 
+try:
+    from urllib3.exceptions import InsecureRequestWarning
+except ImportError:
+    # on some weird configuration the urllib3 is not present
+    # disabling all warnings better than worrying the users and breaking CLI
+    InsecureRequestWarning = Warning
+
+
 # Python 2.7 compliance
 try:
     from functools import lru_cache
-except ImportError as exception:
-    def identity(*args, **kwargs):
-        """
-        A dummy decorator that does nothing
-        """
-
-        def wrapper(function):
-            """
-            Like literally waste of space...
-            """
-            return function
-
-        return wrapper
-
-
-    lru_cache = identity
-
-
-raven_client = RavenClient(
-    'https://4935170ea1284f9e8c3a0c7552cdb5bd:ac7d8158d3b24bc4aa4ea4d628c616e0@sentry.tensorport.com/5'
-)
-
+except ImportError:
+    from backports.functools_lru_cache import lru_cache
 
 LOCAL_DEV = True if os.environ.get('JUST_DEBUG', 'False').upper() == "TRUE" else False
 
@@ -121,7 +109,7 @@ class ClusteroneClient(object):
     Clusterone API Client
     ^^^^^^^^^^^^^^^^^^^^^
 
-    Clusterone Client (tport for short) is a simple Python module that is used to get most up_to_date API schema,
+    Clusterone Client (just for short) is a simple Python module that is used to get most up_to_date API schema,
     and execute API calls.
 
     """
@@ -165,13 +153,13 @@ class ClusteroneClient(object):
         return self.api_url.replace('api', 'matrix')
 
     def __init__(self, token="", username="", environment='', use_in_memory_schema=True, schema_json_path=None,
-            api_url=None):
+                 api_url=None, tls=True):
 
         if not api_url:
-            # TODO: Do something nasty here
-            pass
+            raise TypeError("Missing parameter 'api_url'")
 
         self.api_url = api_url
+        self.tls = tls
 
         # TODO replace this with proper url generator with urllib ASAP
         self.api_schema_url = "{}{}".format(api_url, "schema/")
@@ -190,59 +178,46 @@ class ClusteroneClient(object):
                     click.get_app_dir('clusterone')).join('schema.json')
 
         # Init CoreAPI Client
-        self.transport = self.get_transport()
+        self.transport = self.get_transport(tls=self.tls)
         self.decoders = [codecs.CoreJSONCodec(), codecs.JSONCodec(), codecs.DownloadCodec()]
         self.api_client = Client(
             transports=[self.transport], decoders=self.decoders)
 
-        # Get Schema
-        self.api_schema = self.download_schema()
+        # Don't download schema on __init__, see: client_action for schema acquisition
+        self.api_schema = None
 
         super(ClusteroneClient, self).__init__()
 
-    def get_transport(self):
+    def get_transport(self, tls):
         """
         Creates HTTPTransport with auth header information
-        :param token:
-        :return: HTTPTransport
         """
 
-        # This is a dirty, dirty hack - disabling SSL checks!!!
-        # Remove this after fixing SSL on Roche!
-        import requests
+        # Note: I don't want to touch it RIGHT now, but if you read this and have couple of minutes
+        # and a working test environment - you should
+        # TODO: Move it to top level / replace it with functools.partialmethod with corresponding polyfill
+        # TODO: Test it - need testing environment with certificates not recognized by user CA
         from functools import partial
 
-        class partialmethod(partial):
+        class PartialMethod(partial):
             def __get__(self, instance, owner):
                 if instance is None:
                     return self
 
                 return partial(self.func, instance, *(self.args or ()), **(self.keywords or {}))
 
-        # This disables the SSL warnings that are raised on insecure connection
-        import warnings
+        session = requests.Session()
 
-        try:
-            from urllib3.exceptions import InsecureRequestWarning
+        auth = TokenAuthentication(token=self.token, scheme="JWT") if self.token else None
+        if self.token and LOCAL_DEV:
+            print("Using Token: {}*****".format(self.token[:4]))
+
+        if not tls:
+            # disable requests lib verification
+            session.send = PartialMethod(session.send, verify=False)
             warnings.simplefilter('ignore', InsecureRequestWarning)
-        except ImportError:
-            # on some weird configuration the Urllib3 is not present
-            # this is better than worrying the users and breaking CLI
-            warnings.simplefilter('ignore', Warning)
 
-
-        if self.token:
-            if LOCAL_DEV:
-                print('Using Token: %s************' % self.token[:4])
-            auth = TokenAuthentication(token=self.token, scheme='JWT')
-            _session = requests.Session()
-            _session.send = partialmethod(_session.send, verify=False)
-            #TODO: Fix this header passing!!!!!!!!
-            return transports.HTTPTransport(headers={'Authorization': '%s %s' % ('JWT', self.token)}, session=_session)
-        else:
-            _session = requests.Session()
-            _session.send = partialmethod(_session.send, verify=False)
-            return transports.HTTPTransport(session=_session)
+        return transports.HTTPTransport(auth=auth, session=session)
 
     def get_schema_json(self):
         """
@@ -312,7 +287,7 @@ class ClusteroneClient(object):
             print('Cannot download API Schema: %s' % str(e))
             raise
 
-    def client_action(self, actions_keys, params=None, validate=False):
+    def client_action(self, actions_keys, params=None, validate=True):
         """
         Wrapper for Client.action that set decoders, transports and schema document
         :param token:
@@ -322,6 +297,10 @@ class ClusteroneClient(object):
         :param validate:
         :return:
         """
+
+        if not self.api_schema:
+            self.api_schema = self.download_schema()
+
         try:
             data = self.api_client.action(
                 self.api_schema, actions_keys, params=params, validate=validate)
@@ -333,7 +312,7 @@ class ClusteroneClient(object):
         except coreapi.exceptions.ErrorMessage as exc:
             #TODO: Throtling, server error, gateway timeout, maintanance mode
             # Handle S3 Bucket name
-            if "messages" in exc.error._data:
+            if hasattr(exc, 'error') and "S3 Bucket" in exc.error._data.get('messages', [''])[0]:
                 raise client_exceptions.BucketNameNotAvaliable()
             if 'non_field_errors' in exc.error and exc.error['non_field_errors']:
                 if (exc.error.title == '400 Bad Request') and exc.error._data['non_field_errors']._data[0] == 'Unable to log in with provided credentials.':
@@ -341,12 +320,12 @@ class ClusteroneClient(object):
             else:
                 # TODO refactor the hell out of this
                 if "400" in exc.error._title:
-                    if "Enter a valid \"slug\" consisting of letters, numbers, underscores or hyphens." in exc.error._data["display_name"][0]:
+                    if "Enter a valid \"slug\" consisting of letters, numbers, underscores or hyphens." in exc.error._data.get("display_name", [''])[0]:
                         raise client_exceptions.InvalidProjectName()
-                    elif "Project name is not unique" in exc.error._data["display_name"][0]:
+                    elif "Project name is not unique" in exc.error._data.get("display_name", [''])[0]:
                         raise client_exceptions.DuplicateProjectName()
                     else:
-                        print("API Error: %s" % exc.error)
+                        raise
                 if "403" in exc.error._title and 'You do not have enough resources to start' in exc.error._data['detail']:
                     raise client_exceptions.InsufficientResources()
                 if "500" in exc.error._title:
@@ -367,7 +346,7 @@ class ClusteroneClient(object):
         """
 
         self.token = None
-        self.transport = self.get_transport()
+        self.transport = self.get_transport(tls=self.tls)
         self.api_client = Client(
             transports=[self.transport], decoders=self.decoders)
 
@@ -392,7 +371,7 @@ class ClusteroneClient(object):
                 return None, message
 
             self.token = response.get('token')
-            self.transport = self.get_transport()
+            self.transport = self.get_transport(tls=self.tls)
             self.api_client = Client(
                 transports=[self.transport], decoders=self.decoders)
             self.api_schema = self.download_schema()
@@ -455,7 +434,7 @@ class ClusteroneClient(object):
                     raise client_exceptions.DuplicateProjectName()
                 else:
                     print("Couldn't create a project thru API, error: %s" % str(exception))
-                    #raven_client.captureException()
+
                     return False
 
     def get_project(self, name, username=None):
@@ -477,7 +456,7 @@ class ClusteroneClient(object):
                 raise client_exceptions.NonExistantProject()
             else:
                 print("Couldn't fetch a project, error: %s" % str(e))
-                #raven_client.captureException()
+
                 return False
 
     def get_projects(self, owner=None, writer=None, reader=None):
@@ -500,7 +479,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't fetch a project, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def delete_project(self, name, username):
@@ -516,7 +495,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't delete a project, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def delete_dataset(self, name, username):
@@ -533,7 +512,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't delete a dataset, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def get_dataset(self, name, username):
@@ -547,13 +526,8 @@ class ClusteroneClient(object):
                 'username': username
             }, validate=False)
             return response
-        except Exception as e:
-            if "404" in e.error._title:
-                raise client_exceptions.NonExistantDataset()
-            else:
-                print("Couldn't fetch a dataset, error: %s" % str(e))
-                #raven_client.captureException()
-                return False
+        except ErrorMessage as e:
+            handle_api_error(e, NotebookCreationError)
 
     def get_datasets(self, owner=None, reader=None, writer=None):
         """
@@ -571,7 +545,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't fetch a datasets, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def get_events(self):
@@ -581,7 +555,7 @@ class ClusteroneClient(object):
         """
         # TODO: add various ownership levels
         # TODO: what can this return? - discuss with Michał -> potencial edge cases
-        # Error message: "Failed to query recent events. Perhaps you have not started a job yet. Try 'tport run'."
+        # Error message: "Failed to query recent events. Perhaps you have not started a job yet. Try 'just run'."
         response = self.client_action(
             ['events', 'list'], params={}, validate=False)
         return response
@@ -601,7 +575,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't create event, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     @lru_cache(maxsize=1)
@@ -615,7 +589,7 @@ class ClusteroneClient(object):
                 ['instance-types', 'list'], params=params, validate=False)
             return response.get('results')
         except Exception as e:
-            #raven_client.captureException()
+
             print("Couldn't fetch list of instances, error: %s" % str(e))
 
     @lru_cache(maxsize=1)
@@ -631,7 +605,7 @@ class ClusteroneClient(object):
             return response.get('results')
         #TODO: WHY LEO, WHY?!!!!!!!
         except Exception as e:
-            #raven_client.captureException()
+
             print("Couldn't fetch list of frameworks, error: %s" % str(e))
 
     def get_tf_versions(self, params=None):
@@ -641,7 +615,7 @@ class ClusteroneClient(object):
         """
         return self.get_frameworks(params)
 
-    def get_jobs(self, params=None):
+    def get_jobs(self, action_entity='jobs', params=None):
         """
         Get List of User Running Jobs
         :return: List of Jobs JSONs
@@ -652,11 +626,11 @@ class ClusteroneClient(object):
             else:
                 params = {'limit': 200}
             response = self.client_action(
-                ['jobs', 'list'], params=params, validate=False)
+                [action_entity, 'list'], params=params, validate=False)
             return response
         except Exception as e:
             print("Couldn't fetch a project, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def get_job(self, params=None):
@@ -670,7 +644,7 @@ class ClusteroneClient(object):
             return response
         except Exception as e:
             print("Couldn't fetch a job, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def create_job(self, name, description=None, parameters=None):
@@ -678,26 +652,60 @@ class ClusteroneClient(object):
         create a Job, require repository ID
         :return:
         """
-        project_id = parameters['code']
-        datasets_set = parameters['datasets_set']
-        git_hash = parameters['code_commit']
+        request_parameters = self._prepare_request_parameters(name, description, parameters)
 
         try:
-            response = self.client_action(['jobs', 'create'], params={
-                'repository': project_id,
-                'display_name': name,
-                'description': description,
-                'parameters': parameters,
-                'datasets_set': datasets_set,
-                'git_commit_hash': git_hash
-            }, validate=True)
+            response = self.client_action(['jobs', 'create'], params=request_parameters, validate=True)
 
             return response
-        except Exception as error:
-            print("Couldn't create a job, error: %s" % str(error))
-            #raven_client.captureException()
+        except Exception as e:
+            try:
+                error_message = e.error._data['parameters']['workers']['non_field_errors'][0]
+                if "Wrong number of GPUs." in error_message:
+
+                    words = error_message.split()
+                    instance_type = words[4][1: -1]
+                    max_gpus = words[11][:-1]
+
+                    raise WrongNumberOfGPUs(instance_type, max_gpus)
+            except (AttributeError, KeyError):
+                pass
+            try:
+                if 'No commits found in the project repository.' in e.error._data['messages']:
+                    raise NoCommitsInProjectFound()
+            except (AttributeError, KeyError):
+                pass
+
+            print("Couldn't create a job, error: %s" % str(e))
+
             raise
 
+    @classmethod
+    def _prepare_request_parameters(cls, name, description, parameters):
+        request_parameters = {}
+
+        # if parameter not provided, it should not be sent to the API
+        if parameters['datasets_set'] is not None:
+            request_parameters['datasets_set'] = parameters['datasets_set']
+
+        if parameters['git_commit_hash'] is not None:
+            request_parameters['git_commit_hash'] = parameters['git_commit_hash']
+
+        request_parameters['repository'] = parameters.pop('repository')
+        request_parameters['display_name'] = name
+        request_parameters['description'] = description
+        request_parameters['parameters'] = parameters
+        return request_parameters
+
+    @staticmethod
+    def _pop_from_source_to_target_if_exists(source, target, key):
+        """If key exists in source (parameters) dict - move the key:value to target (request_parameters) dict"""
+        try:
+            value = source.pop(key)
+            target[key] = value
+        except KeyError:
+            pass
+
     def delete_job(self, job_id):
         """
         Deletes a Job
@@ -714,9 +722,8 @@ class ClusteroneClient(object):
         :return:
         """
         try:
-            response = self.client_action(['jobs', 'partial_update'], params={
+            response = self.client_action(['jobs', 'start'], params={
                 'job_id': job_id,
-                'status': 'started'
             }, validate=True)
             return response
         except client_exceptions.InsufficientResources as exception:
@@ -726,7 +733,7 @@ class ClusteroneClient(object):
                 raise client_exceptions._NonExistantJob()
 
             print("Couldn't start a job, error: %s" % str(exception))
-            #raven_client.captureException()
+
             return False
 
     def stop_job(self, job_id):
@@ -735,14 +742,13 @@ class ClusteroneClient(object):
         :return:
         """
         try:
-            response = self.client_action(['jobs', 'partial_update'], params={
+            response = self.client_action(['jobs', 'stop'], params={
                 'job_id': job_id,
-                'status': 'stopped'
             }, validate=True)
             return response
         except Exception as e:
             print("Couldn't stop a job, error: %s" % str(e))
-            #raven_client.captureException()
+
             return False
 
     def get_file_list(self, job_id):
@@ -761,7 +767,6 @@ class ClusteroneClient(object):
                 return []
         except Exception as e:
             print("Couldn't find a job or files, error: %s" % str(e))
-            #raven_client.captureException()
             return False
 
     def download_file(self, job_id, filename):
@@ -778,5 +783,12 @@ class ClusteroneClient(object):
             return download
         except Exception as e:
             print("Download file %s error: %s" % (filename, str(e)))
-            #raven_client.captureException()
+
             return False
+
+    def get_notebooks(self, params=None):
+        """
+        Get list of user's notebooks
+        :return: List of Jobs JSONs
+        """
+        return self.get_jobs(action_entity='notebooks', params=params)
