@@ -7,7 +7,7 @@ from .path_to import path_to_job_id
 from .path_to import path_to_dataset
 
 from .time_limit_to_minutes import main as time_limit_to_minutes
-from .make_table import main as make_table
+from .make_table import *
 from .job_serializer import main as serialize_job
 
 from .choice import Choice, lazy_property, lazify
