@@ -51,19 +51,20 @@ def path_to_job_id(job_path, context=None):
 
     return job_id
 
-def path_to_dataset(dataset_path, context=None):
-    """
-    Coverts dataset_path [format. username/dataset] to ClusterOne dataset_id
-    """
 
-    client, session = context.client, context.session
+def path_to_dataset(dataset_path, context):
+    """Coverts dataset_path [format. username/dataset] to dataset's dict representation"""
+
+    client = context.client
+    session = context.session
 
     dataset_tokens = dataset_path.split('/')
     if len(dataset_tokens) == 1:
         dataset_tokens = [session.get("username")] + dataset_tokens
 
     if not len(dataset_tokens) == 2:
-        raise BadParameter(param_hint="dataset path", message="Please provide a valid dataset path. The format is \"username/dataset\".")
+        raise BadParameter(param_hint="dataset path",
+                           message='Please provide a valid dataset path. The format is "username/dataset".')
 
     username, dataset_name = dataset_tokens
     dataset = client.get_dataset(dataset_name, username)
