@@ -1,5 +1,5 @@
 import requests
-from distutils.version import LooseVersion as serialize_version
+from distutils.version import LooseVersion
 
 import clusterone
 
@@ -10,18 +10,18 @@ PRERELEASE_SUFFIXES = ['dev', 'a', 'b', 'rc']
 
 
 def is_latest_version():
+    """
+    Performs version check against Pypi
+    """
     # TODO: Move this to function signature after removing 2.7 compliance
     # type: () -> bool
 
-    stable_versions = filter(is_stable, get_pypi_versions())
+    remote_stable_versions = [LooseVersion(version) for version in get_pypi_versions() if is_stable(version)]
+    remote_latest_stable = max(remote_stable_versions)
 
-    try:
-        latest_stable, current = map(serialize_version, (next(stable_versions), clusterone.__version__))
-    except TypeError as exception:
-        # Python 2.7 compliance, filter return array, not iterator
-        latest_stable, current = map(serialize_version, (stable_versions[0], clusterone.__version__))
+    current = LooseVersion(clusterone.__version__)
 
-    return current >= latest_stable
+    return current >= remote_latest_stable
 
 
 def is_stable(version): return not any(suffix in version for suffix in PRERELEASE_SUFFIXES)
@@ -33,5 +33,5 @@ def get_pypi_versions():
     # TODO: Move this to function signature after removing 2.7 compliance
     # type: () -> [str]
 
-    response_data = requests.get(PYPI_VERSIONS_URL).json()["releases"]
-    return reversed(sorted(response_data.keys()))
+    response_data = requests.get(PYPI_VERSIONS_URL).json()
+    return response_data["releases"].keys()
